==> Bundle-Encode-0.03.tar.gz: Bundle-Encode-0.03/lib/Bundle/Encode.pm <==
package Bundle::Encode;


our $VERSION = '0.03';


1;
__END__

=head1 NAME

Bundle::Encode - A bundle to install Encode modules and dependencies

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::Encode'
  

=head1 CONTENTS

Text::Iconv

Module::Build

Module::Build::Compat

Test::Simple

Test::More

Unicode::Japanese

CGI

ExtUtils::CBuilder

XML::Parser::Expat

IO::File

MIME::Base64 

Getopt::Std

Getopt::Long

Unicode::Normalize

Font::TTF

Compress::Zlib

Spiffy

Cwd

File::Find

File::Path

FindBin

Config

Test::Builder

Test::Base

HTML::Entities::Pictogram

XSLoader

IDNA::Punycode

Net::IDN::Nameprep

Unicode::Normalize

Unicode::String

Scalar::Util

Encoding::BER

encoding::split

encoding::warnings

HTML::Encoding

Term::Encoding

XML::Encoding

Template::Provider::Encoding

Catalyst::Plugin::Unicode::Encoding

Email::MIME::Encodings

Convert::Charmap

Encode

Encode::IBM

Encode::compat

Encode::InCharset

Encode::JIS2K

Encode::ZapCP1252

Encode::Unicode::Japanese

Encode::HEBCI

Encode::Detect

Encode::HanConvert

Encode::Registry

Encode::TECkit

Encode::UTR22

Encode::DoubleEncodedUTF8

Encode::First

Encode::JavaScript::UCS

Encode::JP::Mobile

Encode::Punycode

Encode::BOCU1

Encode::BOCU1::XS

Encode::EUCJPMS

Encode::CNMap

Encode::Unicode::UTF7

Encode::IMAPUTF7

Encode::Mapper


=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut

==> Bundle-Encode-0.04.tar.gz: Bundle-Encode-0.04/lib/Bundle/Encode.pm <==
package Bundle::Encode;


our $VERSION = '0.04';


1;
__END__

=head1 NAME

Bundle::Encode - A bundle to install Encode modules and dependencies

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::Encode'
  

=head1 CONTENTS

HTML::Parser

HTML::Entities

HTML::Entities::Numbered

HTML::Entities::Latin2

Template::Stash::HTML::Entities

HTML::Entities::Interpolate

MathML::Entities

MathML::Entities::Approximate

HTML::FromANSI

Lingua::UK::Translit

MHonArc::Encode

Alvis::Convert

MIME::Charset

MIME::Tools

Mail::Header

Mail::Internet

Mail::Field

IO::Stringy

Text::Iconv

Module::Build

Module::Build::Compat

Test::Simple

Test::More

Unicode::Japanese

CGI

ExtUtils::CBuilder

XML::Parser::Expat

XML::XPathScript

IO::File

MIME::Base64 

Getopt::Std

Getopt::Long

Unicode::Normalize

Font::TTF

Compress::Zlib

Spiffy

Cwd

File::Find

File::Path

FindBin

Config

Test

Test::Builder

Test::Base

HTML::Entities::ImodePictogram

XSLoader

IDNA::Punycode

Net::IDN::Nameprep

Unicode::Normalize

Unicode::String

Scalar::Util

Encoding::BER

encoding::split

encoding::warnings

HTML::Encoding

Term::Encoding

XML::Encoding

Template::Provider::Encoding

Catalyst::Plugin::Unicode::Encoding

Email::MIME::Encodings

Convert::Charmap

Encode

Encode::IBM

Encode::compat

Encode::InCharset

Encode::JIS2K

Encode::ZapCP1252

Encode::Unicode::Japanese

Encode::HEBCI

Encode::Detect

Encode::HanConvert

Encode::Registry

Encode::TECkit

Encode::UTR22

Encode::DoubleEncodedUTF8

Encode::First

Encode::JavaScript::UCS

Encode::JP::Mobile

Encode::Punycode

Encode::BOCU1

Encode::BOCU1::XS

Encode::EUCJPMS

Encode::CNMap

Encode::Unicode::UTF7

Encode::IMAPUTF7

Encode::Mapper


=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut
